@@ -9,10 +9,10 @@
 #ifndef KR7ZENCRYPTIONCHECKER_H
 #define KR7ZENCRYPTIONCHECKER_H
 
-#include <unistd.h> // for setsid, see Kr7zEncryptionChecker::setupChildProcess
 #include <signal.h> // for kill
+#include <unistd.h> // for setsid, see Kr7zEncryptionChecker::setupChildProcess
 
-#include <KCoreAddons/KProcess>
+#include <KProcess>
 
 /**
  * Used by ArcHandler.
@@ -24,9 +24,6 @@ class Kr7zEncryptionChecker : public KProcess
 public:
     Kr7zEncryptionChecker();
 
-protected:
-    void setupChildProcess() override;
-
 public slots:
     void receivedOutput();
     bool isEncrypted();
