@@ -12,9 +12,9 @@
 // QtWidgets
 #include <QToolButton>
 
-#include <KWidgetsAddons/KActionMenu>
+#include <KActionMenu>
 
-class KrBookmarkButton: public QToolButton
+class KrBookmarkButton : public QToolButton
 {
     Q_OBJECT
 public:
