@@ -11,15 +11,13 @@
 // QtGui
 #include <QFontMetrics>
 
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
-KrusaderStatus::KrusaderStatus(QWidget *parent):
-    QStatusBar(parent)
+KrusaderStatus::KrusaderStatus(QWidget *parent)
+    : QStatusBar(parent)
 {
     showMessage(i18n("Ready."), 5000);
     setMaximumHeight(QFontMetrics(font()).height() + 2);
 }
 
-KrusaderStatus::~KrusaderStatus()
-= default;
-
+KrusaderStatus::~KrusaderStatus() = default;
