@@ -11,36 +11,42 @@
 // QtCore
 #include <QDataStream>
 #include <QDebug>
+#include <QEvent>
 #include <QFile>
 #include <QTimer>
-#include <QEvent>
 // QtGui
 #include <QKeyEvent>
 // QtWidgets
 #include <QMenuBar>
 #include <QStatusBar>
+#include <QGuiApplication>
 
-#include <KCoreAddons/KProcess>
-#include <KCoreAddons/KShell>
-#include <KConfigCore/KSharedConfig>
-#include <KConfigWidgets/KStandardAction>
-#include <KI18n/KLocalizedString>
-#include <KIOCore/KFileItem>
+#include <KWindowSystem>
+#include <kwaylandextras.h>
+#include <kx11extras.h>
+#include <KActionCollection>
+#include <KFileItem>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KFileItem>
 #include <KParts/Part>
-#include <KWidgetsAddons/KMessageBox>
-#include <KXmlGui/KActionCollection>
-#include <KXmlGui/KShortcutsDialog>
-#include <KXmlGui/KToolBar>
-#include <utility>
+#include <KProcess>
+#include <KSharedConfig>
+#include <KShell>
+#include <KShortcutsDialog>
+#include <KStandardAction>
+#include <KToolBar>
 #include <kxmlgui_version.h>
+#include <utility>
+#include <KParts/NavigationExtension>
 
 #include "../defaults.h"
 #include "../icon.h"
 #include "panelviewer.h"
 #include "viewertabbar.h"
 
-#define VIEW_ICON     "document-preview"
-#define EDIT_ICON     "document-edit"
+#define VIEW_ICON "document-preview"
+#define EDIT_ICON "document-edit"
 #define MODIFIED_ICON "document-save-as"
 
 #define CHECK_MODFIED_INTERVAL 500
@@ -53,21 +59,27 @@ NOTE: Currently the code expects PanelViewer::openUrl() to be called only once
 QList<KrViewer *> KrViewer::viewers;
 
 KrViewer::KrViewer(QWidget *parent)
-    : KParts::MainWindow(parent, Qt::WindowFlags()), manager(this, this),
-      tabWidget(this), sizeX(-1), sizeY(-1)
+    : KParts::MainWindow(parent, Qt::WindowFlags())
+    , manager(this, this)
+    , tabWidget(this)
+    , sizeX(-1)
+    , sizeY(-1)
 {
-    //setWFlags(Qt::WType_TopLevel | WDestructiveClose);
-    setXMLFile("krviewer.rc");   // kpart-related xml file
+    // setWFlags(Qt::WType_TopLevel | WDestructiveClose);
     setHelpMenuEnabled(false);
 
     connect(&manager, &KParts::PartManager::activePartChanged, this, &KrViewer::createGUI);
     connect(&tabWidget, &QTabWidget::currentChanged, this, &KrViewer::tabChanged);
-    connect(&tabWidget, &QTabWidget::tabCloseRequested, this, [=](int index) { tabCloseRequest(index, false); });
+    connect(&tabWidget, &QTabWidget::tabCloseRequested, this, [=](int index) {
+        tabCloseRequest(index, false);
+    });
 
     tabWidget.setDocumentMode(true);
     tabWidget.setMovable(true);
     if (ViewerTabBar *tabBar = tabWidget.tabBar())
-        connect(tabBar, &ViewerTabBar::closeTabSignal, this, [=](int index) { tabCloseRequest(index, false); });
+        connect(tabBar, &ViewerTabBar::closeTabSignal, this, [=](int index) {
+            tabCloseRequest(index, false);
+        });
     setCentralWidget(&tabWidget);
 
     printAction = KStandardAction::print(this, SLOT(print()), nullptr);
@@ -77,24 +89,24 @@ KrViewer::KrViewer(QWidget *parent)
     QAction *tempAction;
     KActionCollection *ac = actionCollection();
 
-#define addCustomMenuAction(name, text, slot, shortcut)\
-    tempAction = ac->addAction(name, this, slot);\
-    tempAction->setText(text);\
-    ac->setDefaultShortcut(tempAction, shortcut);\
+#define addCustomMenuAction(name, text, slot, shortcut)                                                                                                        \
+    tempAction = ac->addAction(name, this, slot);                                                                                                              \
+    tempAction->setText(text);                                                                                                                                 \
+    ac->setDefaultShortcut(tempAction, shortcut);                                                                                                              \
     viewerMenu->addAction(tempAction);
 
-    addCustomMenuAction("genericViewer", i18n("&Generic Viewer"), SLOT(viewGeneric()), Qt::CTRL + Qt::SHIFT + Qt::Key_G);
-    addCustomMenuAction("textViewer", i18n("&Text Viewer"), SLOT(viewText()), Qt::CTRL + Qt::SHIFT + Qt::Key_T);
-    addCustomMenuAction("hexViewer", i18n("&Hex Viewer"), SLOT(viewHex()), Qt::CTRL + Qt::SHIFT + Qt::Key_H);
-    addCustomMenuAction("lister", i18n("&Lister"), SLOT(viewLister()), Qt::CTRL + Qt::SHIFT + Qt::Key_L);
+    addCustomMenuAction("genericViewer", i18n("&Generic Viewer"), SLOT(viewGeneric()), Qt::CTRL | Qt::SHIFT | Qt::Key_G);
+    addCustomMenuAction("textViewer", i18n("&Text Viewer"), SLOT(viewText()), Qt::CTRL | Qt::SHIFT | Qt::Key_T);
+    addCustomMenuAction("hexViewer", i18n("&Hex Viewer"), SLOT(viewHex()), Qt::CTRL | Qt::SHIFT | Qt::Key_H);
+    addCustomMenuAction("lister", i18n("&Lister"), SLOT(viewLister()), Qt::CTRL | Qt::SHIFT | Qt::Key_L);
     viewerMenu->addSeparator();
 
-    addCustomMenuAction("textEditor", i18n("Text &Editor"), SLOT(editText()), Qt::CTRL + Qt::SHIFT + Qt::Key_E);
+    addCustomMenuAction("textEditor", i18n("Text &Editor"), SLOT(editText()), Qt::CTRL | Qt::SHIFT | Qt::Key_E);
     viewerMenu->addSeparator();
 
-    QList<QAction *> actList = menuBar()->actions();
+    const QList<QAction *> actList = menuBar()->actions();
     bool hasPrint = false, hasCopy = false;
-    foreach(QAction *a, actList) {
+    for (QAction *a : actList) {
         if (a->shortcut().matches(printAction->shortcut()) != QKeySequence::NoMatch)
             hasPrint = true;
         if (a->shortcut().matches(copyAction->shortcut()) != QKeySequence::NoMatch)
@@ -114,9 +126,9 @@ KrViewer::KrViewer(QWidget *parent)
 
     detachAction = ac->addAction("detachTab", this, SLOT(detachTab()));
     detachAction->setText(i18n("&Detach Tab"));
-    //no point in detaching only one tab..
+    // no point in detaching only one tab..
     detachAction->setEnabled(false);
-    ac->setDefaultShortcut(detachAction, Qt::META + Qt::Key_D);
+    ac->setDefaultShortcut(detachAction, Qt::META | Qt::Key_D);
     viewerMenu->addAction(detachAction);
 
     quitAction = ac->addAction(KStandardAction::Quit, this, SLOT(close()));
@@ -133,16 +145,15 @@ KrViewer::KrViewer(QWidget *parent)
     tabNextAction = ac->addAction("nextTab", this, SLOT(nextTab()));
     tabNextAction->setText(i18n("&Next Tab"));
     shortcuts = KStandardShortcut::tabNext();
-    shortcuts.append(Qt::CTRL + Qt::Key_Tab);  // reenforce QTabWidget shortcut
+    shortcuts.append(Qt::CTRL | Qt::Key_Tab); // reenforce QTabWidget shortcut
     ac->setDefaultShortcuts(tabNextAction, shortcuts);
 
     tabPrevAction = ac->addAction("prevTab", this, SLOT(prevTab()));
     tabPrevAction->setText(i18n("&Previous Tab"));
     shortcuts = KStandardShortcut::tabPrev();
-    shortcuts.append(Qt::CTRL + Qt::SHIFT + Qt::Key_Tab);  // reenforce QTabWidget shortcut
+    shortcuts.append(Qt::CTRL | Qt::SHIFT | Qt::Key_Tab); // reenforce QTabWidget shortcut
     ac->setDefaultShortcuts(tabPrevAction, shortcuts);
 
-
     tabWidget.setTabsClosable(true);
 
     checkModified();
@@ -156,24 +167,25 @@ KrViewer::KrViewer(QWidget *parent)
     else
         resize(900, 700);
 
-    if (group.readEntry("Window Maximized",  false)) {
+    if (group.readEntry("Window Maximized", false)) {
         setWindowState(windowState() | Qt::WindowMaximized);
     }
 
     // filtering out the key events
-    menuBar() ->installEventFilter(this);
+    menuBar()->installEventFilter(this);
+
+    setupGUI(ToolBar | StatusBar | Save | Create, "krviewer.rc");
 }
 
 KrViewer::~KrViewer()
 {
-    disconnect(&manager, SIGNAL(activePartChanged(KParts::Part*)),
-               this, SLOT(createGUI(KParts::Part*)));
+    disconnect(&manager, SIGNAL(activePartChanged(KParts::Part *)), this, SLOT(createGUI(KParts::Part *)));
 
     viewers.removeAll(this);
 
     // close tabs before deleting tab bar - this avoids Qt bug 26115
     // https://bugreports.qt-project.org/browse/QTBUG-26115
-    while(tabWidget.count())
+    while (tabWidget.count())
         tabCloseRequest(tabWidget.currentIndex(), true);
 
     delete printAction;
@@ -185,15 +197,12 @@ void KrViewer::configureDeps()
     PanelEditor::configureDeps();
 }
 
-void KrViewer::createGUI(KParts::Part* part)
+void KrViewer::createGUI(KParts::Part *part)
 {
     KParts::MainWindow::createGUI(part);
 
     updateActions();
 
-    toolBar() ->show();
-    statusBar() ->show();
-
     // the KParts part may override the viewer shortcuts. We prevent it
     // by installing an event filter on the menuBar() and the part
     reservedKeys.clear();
@@ -204,21 +213,21 @@ void KrViewer::createGUI(KParts::Part* part)
     list << tabCloseAction << tabNextAction << tabPrevAction;
     // getting the key sequences of the viewer menu
     for (int w = 0; w != list.count(); w++) {
-        QAction *act = list[ w ];
-        QList<QKeySequence> sequences = act->shortcuts();
-        foreach(QKeySequence keySeq, sequences) {
-            for(int i = 0; i < keySeq.count(); ++i) {
+        QAction *act = list[w];
+        const QList<QKeySequence> sequences = act->shortcuts();
+        for (QKeySequence keySeq : sequences) {
+            for (int i = 0; i < keySeq.count(); ++i) {
                 reservedKeys.push_back(keySeq[i]);
-                reservedKeyActions.push_back(act); //the same action many times in case of multiple shortcuts
+                reservedKeyActions.push_back(act); // the same action many times in case of multiple shortcuts
             }
         }
     }
 
     // and "fix" the menubar
     viewerMenu->setTitle(i18n("&KrViewer"));
-    QAction * act = menuBar() ->addMenu(viewerMenu);
+    QAction *act = menuBar()->addMenu(viewerMenu);
     act->setData(QVariant(70));
-    menuBar() ->show();
+    menuBar()->show();
 }
 
 void KrViewer::configureShortcuts()
@@ -230,17 +239,17 @@ void KrViewer::configureShortcuts()
 #endif
 }
 
-bool KrViewer::eventFilter(QObject * /* watched */, QEvent * e)
+bool KrViewer::eventFilter(QObject * /* watched */, QEvent *e)
 {
     // TODO: after porting to Qt5/KF5 we never catch *ANY* KeyPress or ShortcutOverride events here anymore.
     // Should look into if there is any way to fix it. Currently if a KPart has same shortcut as KrViewer then
     // it causes a conflict, messagebox shown to user and no action triggered.
     if (e->type() == QEvent::ShortcutOverride) {
-        auto* ke = dynamic_cast<QKeyEvent*>( e);
+        auto *ke = dynamic_cast<QKeyEvent *>(e);
         if (reservedKeys.contains(ke->key())) {
             ke->accept();
 
-            QAction *act = reservedKeyActions[ reservedKeys.indexOf(ke->key())];
+            QAction *act = reservedKeyActions[reservedKeys.indexOf(ke->key())];
             if (act != nullptr) {
                 // don't activate the close functions immediately!
                 // it can cause crash
@@ -253,7 +262,7 @@ bool KrViewer::eventFilter(QObject * /* watched */, QEvent * e)
             return true;
         }
     } else if (e->type() == QEvent::KeyPress) {
-        auto* ke = dynamic_cast<QKeyEvent*>( e);
+        auto *ke = dynamic_cast<QKeyEvent *>(e);
         if (reservedKeys.contains(ke->key())) {
             ke->accept();
             return true;
@@ -262,18 +271,51 @@ bool KrViewer::eventFilter(QObject * /* watched */, QEvent * e)
     return false;
 }
 
-KrViewer* KrViewer::getViewer(bool new_window)
+void KrViewer::activateWindow(QWidget *window)
+{
+    auto focusWindow = qGuiApp->focusWindow();
+    if (focusWindow && KrGlobal::isWaylandPlatform) {
+        // Wayland(and KWin) doesn't allow for a window to come to foreground and
+        // take focus away. The proper way to do this is for the window that has
+        // focus to request a new activation token and pass it to the window that
+        // will come to foreground(eg Viewer). The window to be brought to fore
+        // will then call KWindowSystem::setCurrentXdgActivationToken which will
+        // enable  KWindowSystem::activateWindow() to work. Without the call to
+        // setCurrentXdgActivationToken, the call to
+        // KWindowSystem::activateWindow() will just cause the window to blink in
+        // the task bar requesting attention, but never get focus or come to the
+        // foreground.
+        const int launchedSerial = KWaylandExtras::lastInputSerial(focusWindow);
+        auto conn = std::make_shared<QMetaObject::Connection>();
+        *conn = connect(KWaylandExtras::self(),
+                        &KWaylandExtras::xdgActivationTokenArrived,
+                        window,
+                        [window, launchedSerial, conn](int tokenSerial, const QString &token) {
+                            if (tokenSerial == launchedSerial) {
+                                disconnect(*conn);
+                                KWindowSystem::setCurrentXdgActivationToken(token);
+                                // activateWindow will only work if a new token from the focused window has been set otherwise it will only request attn
+                                KWindowSystem::activateWindow(window->windowHandle());
+                            }
+                        });
+        KWaylandExtras::requestXdgActivationToken(focusWindow, launchedSerial, {});
+    }
+    if (KrGlobal::isX11Platform) {
+        KX11Extras::forceActiveWindow(window->winId());
+    }
+}
+KrViewer *KrViewer::getViewer(bool new_window)
 {
     if (!new_window) {
         if (viewers.isEmpty()) {
-            viewers.prepend(new KrViewer());   // add to first (active)
+            viewers.prepend(new KrViewer()); // add to first (active)
         } else {
             if (viewers.first()->isMinimized()) { // minimized? -> show it again
                 viewers.first()->setWindowState((viewers.first()->windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
                 viewers.first()->show();
             }
             viewers.first()->raise();
-            viewers.first()->activateWindow();
+            activateWindow(viewers.first());
         }
         return viewers.first();
     } else {
@@ -283,7 +325,7 @@ KrViewer* KrViewer::getViewer(bool new_window)
     }
 }
 
-void KrViewer::view(QUrl url, QWidget * parent)
+void KrViewer::view(QUrl url, QWidget *parent)
 {
     KConfigGroup group(krConfig, "General");
     bool defaultWindow = group.readEntry("View In Separate Window", _ViewInSeparateWindow);
@@ -291,19 +333,19 @@ void KrViewer::view(QUrl url, QWidget * parent)
     view(std::move(url), Default, defaultWindow, parent);
 }
 
-void KrViewer::view(QUrl url, Mode mode,  bool new_window, QWidget * parent)
+void KrViewer::view(QUrl url, Mode mode, bool new_window, QWidget *parent)
 {
-    KrViewer* viewer = getViewer(new_window);
+    KrViewer *viewer = getViewer(new_window);
     viewer->viewInternal(std::move(url), mode, parent);
     viewer->show();
 }
 
-void KrViewer::edit(QUrl url, QWidget * parent)
+void KrViewer::edit(QUrl url, QWidget *parent)
 {
     edit(std::move(url), Text, -1, parent);
 }
 
-void KrViewer::edit(const QUrl& url, Mode mode, int new_window, QWidget * parent)
+void KrViewer::edit(const QUrl &url, Mode mode, int new_window, QWidget *parent)
 {
     KConfigGroup group(krConfig, "General");
     QString editor = group.readEntry("Editor", _Editor);
@@ -315,9 +357,7 @@ void KrViewer::edit(const QUrl& url, Mode mode, int new_window, QWidget * parent
         KProcess proc;
         QStringList cmdArgs = KShell::splitArgs(editor, KShell::TildeExpand);
         if (cmdArgs.isEmpty()) {
-            KMessageBox::error(krMainWindow,
-                               i18nc("Arg is a string containing the bad quoting.",
-                                     "Bad quoting in editor command:\n%1", editor));
+            KMessageBox::error(krMainWindow, i18nc("Arg is a string containing the bad quoting.", "Bad quoting in editor command:\n%1", editor));
             return;
         }
         // if the file is local, pass a normal path and not a url. this solves
@@ -328,7 +368,7 @@ void KrViewer::edit(const QUrl& url, Mode mode, int new_window, QWidget * parent
         return;
     }
 
-    KrViewer* viewer = getViewer(new_window);
+    KrViewer *viewer = getViewer(new_window);
     viewer->editInternal(url, mode, parent);
     viewer->show();
 }
@@ -374,14 +414,15 @@ void KrViewer::openUrlFinished(PanelViewerBase *pvb, bool success)
         }
     } else {
         tabCloseRequest(tabWidget.currentIndex(), false);
-      }
+    }
 }
 
 void KrViewer::tabChanged(int index)
 {
     QWidget *w = tabWidget.widget(index);
-    if(!w) return;
-    KParts::ReadOnlyPart *part = dynamic_cast<PanelViewerBase*>(w)->part();
+    if (!w)
+        return;
+    KParts::ReadOnlyPart *part = dynamic_cast<PanelViewerBase *>(w)->part();
     if (part && isPartAdded(part)) {
         manager.setActivePart(part);
         if (part->widget())
@@ -389,9 +430,9 @@ void KrViewer::tabChanged(int index)
     } else
         manager.setActivePart(nullptr);
 
-
     // set this viewer to be the main viewer
-    if (viewers.removeAll(this)) viewers.prepend(this);      // move to first
+    if (viewers.removeAll(this))
+        viewers.prepend(this); // move to first
 }
 
 void KrViewer::tabCloseRequest(int index, bool force)
@@ -421,10 +462,11 @@ void KrViewer::tabCloseRequest(int index, bool force)
     if (tabWidget.count() <= 0) {
         if (returnFocusToThisWidget) {
             returnFocusToThisWidget->raise();
-            returnFocusToThisWidget->activateWindow();
+            activateWindow(returnFocusToThisWidget);
+
         } else {
             krMainWindow->raise();
-            krMainWindow->activateWindow();
+            activateWindow(krMainWindow);
         }
 
         QTimer::singleShot(0, this, &KrViewer::close);
@@ -449,7 +491,7 @@ bool KrViewer::queryClose()
     group.writeEntry("Window Maximized", isMaximized());
 
     for (int i = 0; i != tabWidget.count(); i++) {
-        auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.widget(i));
+        auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.widget(i));
         if (!pvb)
             continue;
 
@@ -463,35 +505,35 @@ bool KrViewer::queryClose()
 
 void KrViewer::viewGeneric()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (pvb)
         viewInternal(pvb->url(), Generic);
 }
 
 void KrViewer::viewText()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (pvb)
         viewInternal(pvb->url(), Text);
 }
 
 void KrViewer::viewLister()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (pvb)
         viewInternal(pvb->url(), Lister);
 }
 
 void KrViewer::viewHex()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (pvb)
         viewInternal(pvb->url(), Hex);
 }
 
 void KrViewer::editText()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (pvb)
         editInternal(pvb->url(), Text);
 }
@@ -500,12 +542,12 @@ void KrViewer::checkModified()
 {
     QTimer::singleShot(CHECK_MODFIED_INTERVAL, this, &KrViewer::checkModified);
 
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (pvb)
         refreshTab(pvb);
 }
 
-void KrViewer::refreshTab(PanelViewerBase* pvb)
+void KrViewer::refreshTab(PanelViewerBase *pvb)
 {
     int ndx = tabWidget.indexOf(pvb);
     tabWidget.setTabText(ndx, makeTabText(pvb));
@@ -522,16 +564,18 @@ void KrViewer::nextTab()
 void KrViewer::prevTab()
 {
     int index = (tabWidget.currentIndex() - 1) % tabWidget.count();
-    while (index < 0) index += tabWidget.count();
+    while (index < 0)
+        index += tabWidget.count();
     tabWidget.setCurrentIndex(index);
 }
 
 void KrViewer::detachTab()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
-    if (!pvb) return;
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
+    if (!pvb)
+        return;
 
-    KrViewer* viewer = getViewer(true);
+    KrViewer *viewer = getViewer(true);
 
     bool wasPartAdded = false;
     KParts::ReadOnlyPart *part = pvb->part();
@@ -546,7 +590,7 @@ void KrViewer::detachTab()
     tabWidget.removeTab(tabWidget.indexOf(pvb));
 
     if (tabWidget.count() == 1) {
-        //no point in detaching only one tab..
+        // no point in detaching only one tab..
         detachAction->setEnabled(false);
         tabWidget.adjustViewerTabBarVisibility();
     }
@@ -568,36 +612,37 @@ void KrViewer::detachTab()
 void KrViewer::changeEvent(QEvent *e)
 {
     if (e->type() == QEvent::ActivationChange && isActiveWindow())
-        if (viewers.removeAll(this)) viewers.prepend(this);      // move to first
+        if (viewers.removeAll(this))
+            viewers.prepend(this); // move to first
 }
 
 void KrViewer::print()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (!pvb || !pvb->part() || !isPartAdded(pvb->part()))
         return;
 
-    KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject(pvb->part());
+    KParts::NavigationExtension *ext = KParts::NavigationExtension::childObject(pvb->part());
     if (ext && ext->isActionEnabled("print"))
         Invoker(ext, SLOT(print())).invoke();
 }
 
 void KrViewer::copy()
 {
-    auto* pvb = dynamic_cast<PanelViewerBase*>(tabWidget.currentWidget());
+    auto *pvb = dynamic_cast<PanelViewerBase *>(tabWidget.currentWidget());
     if (!pvb || !pvb->part() || !isPartAdded(pvb->part()))
         return;
 
-    KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject(pvb->part());
+    KParts::NavigationExtension *ext = KParts::NavigationExtension::childObject(pvb->part());
     if (ext && ext->isActionEnabled("copy"))
         Invoker(ext, SLOT(copy())).invoke();
 }
 
 void KrViewer::updateActions()
 {
-    QList<QAction *> actList = toolBar()->actions();
+    const QList<QAction *> actList = toolBar()->actions();
     bool hasPrint = false, hasCopy = false;
-    foreach(QAction *a, actList) {
+    for (QAction *a : actList) {
         if (a->text() == printAction->text())
             hasPrint = true;
         if (a->text() == copyAction->text())
@@ -609,7 +654,7 @@ void KrViewer::updateActions()
         toolBar()->addAction(copyAction->icon(), copyAction->text(), this, SLOT(copy()));
 }
 
-bool KrViewer::isPartAdded(KParts::Part* part)
+bool KrViewer::isPartAdded(KParts::Part *part)
 {
     return manager.parts().contains(part);
 }
@@ -630,17 +675,15 @@ QString KrViewer::makeTabText(PanelViewerBase *pvb)
     if (pvb->isModified())
         fileName.prepend("*");
 
-    return pvb->isEditor() ?
-            i18nc("filename (filestate)", "%1 (Editing)", fileName) :
-            i18nc("filename (filestate)", "%1 (Viewing)", fileName);
+    return pvb->isEditor() ? // clang-format off
+        i18nc("filename (filestate)", "%1 (Editing)", fileName) :
+        i18nc("filename (filestate)", "%1 (Viewing)", fileName); // clang-format on
 }
 
 QString KrViewer::makeTabToolTip(PanelViewerBase *pvb)
 {
     QString url = pvb->url().toDisplayString(QUrl::PreferLocalFile);
-    return pvb->isEditor() ?
-            i18nc("filestate: filename", "Editing: %1", url) :
-            i18nc("filestate: filename", "Viewing: %1", url);
+    return pvb->isEditor() ? i18nc("filestate: filename", "Editing: %1", url) : i18nc("filestate: filename", "Viewing: %1", url);
 }
 
 QIcon KrViewer::makeTabIcon(PanelViewerBase *pvb)
@@ -662,12 +705,11 @@ void KrViewer::addPart(KParts::ReadOnlyPart *part)
     Q_ASSERT(!isPartAdded(part));
 
     if (isPartAdded(part)) {
-        qDebug()<<"part already added:"<<part;
+        qDebug() << "part already added:" << part;
         return;
     }
 
-    connect(part, SIGNAL(setStatusBarText(QString)),
-            this, SLOT(slotSetStatusBarText(QString)));
+    connect(part, SIGNAL(setStatusBarText(QString)), this, SLOT(slotSetStatusBarText(QString)));
     // filtering out the key events
     part->installEventFilter(this);
 
@@ -684,24 +726,24 @@ void KrViewer::removePart(KParts::ReadOnlyPart *part)
         part->removeEventFilter(this);
         manager.removePart(part);
     } else
-        qDebug()<<"part hasn't been added:"<<part;
+        qDebug() << "part hasn't been added:" << part;
 }
 
 void KrViewer::viewInternal(QUrl url, Mode mode, QWidget *parent)
 {
     returnFocusTo = parent;
 
-    PanelViewerBase* viewWidget = new PanelViewer(&tabWidget, mode);
+    PanelViewerBase *viewWidget = new PanelViewer(&tabWidget, mode);
 
     addTab(viewWidget);
     viewWidget->openUrl(std::move(url));
 }
 
-void KrViewer::editInternal(QUrl url, Mode mode, QWidget * parent)
+void KrViewer::editInternal(QUrl url, Mode mode, QWidget *parent)
 {
     returnFocusTo = parent;
 
-    PanelViewerBase* editWidget = new PanelEditor(&tabWidget, mode);
+    PanelViewerBase *editWidget = new PanelEditor(&tabWidget, mode);
 
     addTab(editWidget);
     editWidget->openUrl(std::move(url));
