@@ -8,17 +8,18 @@
 #include "lister.h"
 
 // QtCore
+#include <QDate>
 #include <QFile>
 #include <QRect>
-#include <QDate>
 #include <QTemporaryFile>
 #include <QTextStream>
+#include <QStringConverter>
 // QtGui
-#include <QPainter>
+#include <QClipboard>
 #include <QFontDatabase>
 #include <QFontMetrics>
-#include <QClipboard>
 #include <QKeyEvent>
+#include <QPainter>
 // QtWidgets
 #include <QApplication>
 #include <QFileDialog>
@@ -29,37 +30,40 @@
 #include <QMenu>
 #include <QProgressBar>
 #include <QPushButton>
-#include <QSpacerItem>
 #include <QScrollBar>
+#include <QSpacerItem>
 #include <QToolButton>
 // QtPrintSupport
 #include <QPrintDialog>
 #include <QPrinter>
 
-#include <KCodecs/KCharsets>
-#include <KConfigCore/KSharedConfig>
-#include <KCoreAddons/KJobTrackerInterface>
-#include <KI18n/KLocalizedString>
+#include <KActionCollection>
+#include <KCharsets>
 #include <KIO/CopyJob>
-#include <KIO/TransferJob>
 #include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
+#include <KIO/TransferJob>
+#include <KIO/JobTracker>
+#include <KJobTrackerInterface>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KParts/GUIActivateEvent>
-#include <KWidgetsAddons/KMessageBox>
-#include <KXmlGui/KActionCollection>
+#include <KSharedConfig>
 
-#include "../krglobal.h"
-#include "../icon.h"
-#include "../kractions.h"
 #include "../GUI/krremoteencodingmenu.h"
 #include "../compat.h"
+#include "../icon.h"
+#include "../kractions.h"
+#include "../krglobal.h"
 
-#define  SEARCH_CACHE_CHARS 100000
-#define  SEARCH_MAX_ROW_LEN 4000
-#define  CONTROL_CHAR       752
-#define  CACHE_SIZE         1048576 // cache size set to 1MiB
+#define SEARCH_CACHE_CHARS 100000
+#define SEARCH_MAX_ROW_LEN 4000
+#define CONTROL_CHAR 752
+#define CACHE_SIZE 1048576 // cache size set to 1MiB
 
-
-ListerTextArea::ListerTextArea(Lister *lister, QWidget *parent) : KTextEdit(parent), _lister(lister)
+ListerTextArea::ListerTextArea(Lister *lister, QWidget *parent)
+    : KTextEdit(parent)
+    , _lister(lister)
 {
     connect(this, &QTextEdit::cursorPositionChanged, this, &ListerTextArea::slotCursorPositionChanged);
     _tabWidth = 4;
@@ -67,8 +71,12 @@ ListerTextArea::ListerTextArea(Lister *lister, QWidget *parent) : KTextEdit(pare
     setLineWrapMode(QTextEdit::NoWrap);
 
     // zoom shortcuts
-    connect(new QShortcut(QKeySequence("Ctrl++"), this), &QShortcut::activated, this, [=]() { zoomIn(); });
-    connect(new QShortcut(QKeySequence("Ctrl+-"), this), &QShortcut::activated, this, [=]() { zoomOut(); });
+    connect(new QShortcut(QKeySequence("Ctrl++"), this), &QShortcut::activated, this, [=]() {
+        zoomIn();
+    });
+    connect(new QShortcut(QKeySequence("Ctrl+-"), this), &QShortcut::activated, this, [=]() {
+        zoomOut();
+    });
 
     // start cursor blinking
     connect(&_blinkTimer, &QTimer::timeout, this, [=] {
@@ -100,7 +108,7 @@ void ListerTextArea::sizeChanged()
     redrawTextArea(true);
 }
 
-void ListerTextArea::resizeEvent(QResizeEvent * event)
+void ListerTextArea::resizeEvent(QResizeEvent *event)
 {
     KTextEdit::resizeEvent(event);
     redrawTextArea();
@@ -115,12 +123,14 @@ void ListerTextArea::calculateText(const bool forcedUpdate)
 
     // This is quite accurate (although not perfect) way of getting
     // a single character width along with its surrounding space.
-    const double fontWidth = (fm.horizontalAdvance("WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW") - fm.horizontalAdvance("W")) / 99.0;
+    const double fontWidth = (fm.horizontalAdvance("WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW")
+                              - fm.horizontalAdvance("W"))
+        / 99.0;
 
     const int sizeY = contentRect.height() / fontHeight;
     _pageSize = sizeY;
 
-    const int textViewportWidth = std::max(contentRect.width() - (int) fontWidth, 0);
+    const int textViewportWidth = std::max(contentRect.width() - (int)fontWidth, 0);
 
     setTabStopDistance(fontWidth * _tabWidth);
 
@@ -143,7 +153,6 @@ void ListerTextArea::calculateText(const bool forcedUpdate)
     list << listRemn;
 
     if (list != _rowContent) {
-
         _cursorBlinkMutex.lock();
         _blinkTimer.stop();
         setCursorWidth(0);
@@ -171,7 +180,7 @@ qint64 ListerTextArea::textToFilePositionOnScreen(const int x, const int y, bool
     if (y >= _rowStarts.count()) {
         return 0;
     }
-    const qint64 rowStart = _rowStarts[ y ];
+    const qint64 rowStart = _rowStarts[y];
     if (x == 0) {
         return rowStart;
     }
@@ -185,11 +194,12 @@ qint64 ListerTextArea::textToFilePositionOnScreen(const int x, const int y, bool
     }
 
     // we can't use fromUnicode because of the invalid encoded chars
-    const int maxBytes = 2 * _sizeX * MAX_CHAR_LENGTH;
+    const qsizetype maxBytes = 2 * _sizeX * MAX_CHAR_LENGTH;
     QByteArray chunk = _lister->cacheChunk(rowStart, maxBytes);
 
-    QTextStream stream(&chunk);
-    stream.setCodec(_lister->codec());
+    QString s = _lister->codec()->toUnicode(chunk);
+    QTextStream stream(&s);
+
     stream.read(x);
     return rowStart + stream.pos();
 }
@@ -205,7 +215,7 @@ void ListerTextArea::fileToTextPositionOnScreen(const qint64 p, const bool isfir
 
     // find row
     y = 0;
-    while (y < _rowStarts.count() && _rowStarts[ y ] <= p) {
+    while (y < _rowStarts.count() && _rowStarts[y] <= p) {
         y++;
     }
     y--;
@@ -214,27 +224,28 @@ void ListerTextArea::fileToTextPositionOnScreen(const qint64 p, const bool isfir
         return;
     }
 
-    const qint64 rowStart = _rowStarts[ y ];
+    const qint64 rowStart = _rowStarts[y];
     if (_hexMode) {
         x = _lister->hexIndexToPosition(_sizeX, (int)(p - rowStart));
         return;
     }
 
     // find column
-    const int maxBytes = 2 * _sizeX * MAX_CHAR_LENGTH;
+    const qsizetype maxBytes = 2 * _sizeX * MAX_CHAR_LENGTH;
     x = 0;
     if (rowStart >= p) {
         if ((rowStart == p) && !isfirst && y > 0) {
-            const qint64 previousRow = _rowStarts[ y - 1 ];
+            const qint64 previousRow = _rowStarts[y - 1];
             const QByteArray chunk = _lister->cacheChunk(previousRow, maxBytes);
             QByteArray cachedBuffer = chunk.left(static_cast<int>(p - previousRow));
+            QTextCodec *codec = _lister->codec();
+            QString decoded = codec->toUnicode(cachedBuffer);
+            QTextStream stream(&decoded);
 
-            QTextStream stream(&cachedBuffer);
-            stream.setCodec(_lister->codec());
-            stream.read(_rowContent[ y - 1].length());
+            stream.read(_rowContent[y - 1].length());
             if (previousRow + stream.pos() == p) {
                 y--;
-                x = _rowContent[ y ].length();
+                x = static_cast<int>(_rowContent[y].length());
             }
         }
         return;
@@ -243,7 +254,7 @@ void ListerTextArea::fileToTextPositionOnScreen(const qint64 p, const bool isfir
     const QByteArray chunk = _lister->cacheChunk(rowStart, maxBytes);
     const QByteArray cachedBuffer = chunk.left(static_cast<int>(p - rowStart));
 
-    x = _lister->codec()->toUnicode(cachedBuffer).length();
+    x = static_cast<int>(_lister->codec()->toUnicode(cachedBuffer).length());
 }
 
 void ListerTextArea::getCursorPosition(int &x, int &y)
@@ -255,8 +266,8 @@ void ListerTextArea::getScreenPosition(const int position, int &x, int &y)
 {
     x = position;
     y = 0;
-    foreach (const QString &row, _rowContent) {
-        const int rowLen = row.length() + 1;
+    for (const QString &row : std::as_const(_rowContent)) {
+        const int rowLen = static_cast<int>(row.length()) + 1;
         if (x < rowLen) {
             return;
         }
@@ -279,14 +290,14 @@ void ListerTextArea::setCursorPositionOnScreen(const int x, const int y, const i
 
         if (finalY == -2) {
             finalY = _sizeY;
-            finalX = (_rowContent.count() > _sizeY) ? _rowContent[ _sizeY ].length() : 0;
+            finalX = (_rowContent.count() > _sizeY) ? static_cast<int>(_rowContent[_sizeY].length()) : 0;
         } else
             finalX = finalY = 0;
     }
 
-    const int realSizeY = std::min(_sizeY + 1, _rowContent.count());
+    const int realSizeY = std::min(_sizeY + 1, static_cast<int>(_rowContent.count()));
 
-    const auto setUpCursor = [&] (const int cursorX, const int cursorY, const QTextCursor::MoveMode mode) -> bool {
+    const auto setUpCursor = [&](const int cursorX, const int cursorY, const QTextCursor::MoveMode mode) -> bool {
         if (cursorY > realSizeY) {
             return false;
         }
@@ -298,9 +309,9 @@ void ListerTextArea::setCursorPositionOnScreen(const int x, const int y, const i
             moveCursor(QTextCursor::Down, mode);
         }
 
-        int finalCursorX = cursorX;
-        if (_rowContent.count() > cursorY && finalCursorX > _rowContent[ cursorY ].length()) {
-            finalCursorX = _rowContent[ cursorY ].length();
+        qsizetype finalCursorX = cursorX;
+        if (_rowContent.count() > cursorY && finalCursorX > _rowContent[cursorY].length()) {
+            finalCursorX = _rowContent[cursorY].length();
         }
 
         for (int i = 0; i < finalCursorX; i++) {
@@ -316,7 +327,6 @@ void ListerTextArea::setCursorPositionOnScreen(const int x, const int y, const i
 
     // set cursor anchor
     if (anchorX != -1 && anchorY != -1) {
-
         const bool canContinue = setUpCursor(anchorX, anchorY, mode);
         if (!canContinue) {
             return;
@@ -370,7 +380,7 @@ void ListerTextArea::setCursorPositionInDocument(const qint64 p, const bool isfi
                 anchorX = 0;
             }
             if (anchorBelow && _rowContent.count() > 0) {
-                anchorX = _rowContent[ 0 ].length();
+                anchorX = static_cast<int>(_rowContent[0].length());
             }
         }
 
@@ -427,7 +437,7 @@ QString ListerTextArea::readSection(const qint64 p1, const qint64 p2)
     QScopedPointer<QTextDecoder> decoder(_lister->codec()->makeDecoder());
 
     do {
-        const int maxBytes = std::min(_sizeX * _sizeY * MAX_CHAR_LENGTH, (int) (sel2 - pos));
+        const qint64 maxBytes = std::min(qint64(_sizeX) * _sizeY * MAX_CHAR_LENGTH, sel2 - pos);
         const QByteArray chunk = _lister->cacheChunk(pos, maxBytes);
         if (chunk.isEmpty())
             break;
@@ -438,7 +448,7 @@ QString ListerTextArea::readSection(const qint64 p1, const qint64 p2)
     return section;
 }
 
-QStringList ListerTextArea::readLines(qint64 filePos, qint64 &endPos, const int lines, QList<qint64> * locs)
+QStringList ListerTextArea::readLines(qint64 filePos, qint64 &endPos, const int lines, QList<qint64> *locs)
 {
     QStringList list;
 
@@ -462,7 +472,7 @@ QStringList ListerTextArea::readLines(qint64 filePos, qint64 &endPos, const int
     }
 
     endPos = filePos;
-    const int maxBytes = _sizeX * _sizeY * MAX_CHAR_LENGTH;
+    const qsizetype maxBytes = _sizeX * _sizeY * MAX_CHAR_LENGTH;
     const QByteArray chunk = _lister->cacheChunk(filePos, maxBytes);
     if (chunk.isEmpty())
         return list;
@@ -474,7 +484,7 @@ QStringList ListerTextArea::readLines(qint64 filePos, qint64 &endPos, const int
         (*locs) << filePos;
     bool skipImmediateNewline = false;
 
-    const auto performNewline = [&] (qint64 nextRowStartOffset) {
+    const auto performNewline = [&](qint64 nextRowStartOffset) {
         list << row;
         effLength = 0;
         row = "";
@@ -492,7 +502,7 @@ QStringList ListerTextArea::readLines(qint64 filePos, qint64 &endPos, const int
             continue;
         }
 
-        if ((chr[ 0 ] < 32) && (chr[ 0 ] != '\n') && (chr[ 0 ] != '\t')) {
+        if ((chr[0] < QChar(32)) && (chr[0] != '\n') && (chr[0] != '\t')) {
             chr = QChar(CONTROL_CHAR);
         }
 
@@ -545,7 +555,7 @@ void ListerTextArea::setUpScrollBar()
         if (list.count() <= _sizeY) {
             _lastPageStartPos = 0;
         } else {
-            readLines(pageStartPos, _lastPageStartPos, list.count() - _sizeY);
+            readLines(pageStartPos, _lastPageStartPos, static_cast<int>(list.count()) - _sizeY);
         }
 
         const qint64 maximum = (_lastPageStartPos > SLIDER_MAX) ? SLIDER_MAX : _lastPageStartPos;
@@ -559,7 +569,7 @@ void ListerTextArea::setUpScrollBar()
     }
 }
 
-void ListerTextArea::keyPressEvent(QKeyEvent * ke)
+void ListerTextArea::keyPressEvent(QKeyEvent *ke)
 {
     if (KrGlobal::copyShortcut == QKeySequence(ke->key() | ke->modifiers())) {
         copySelectedToClipboard();
@@ -594,15 +604,13 @@ void ListerTextArea::keyPressEvent(QKeyEvent * ke)
             getCursorPosition(x, y);
             if (y == 0 && x == 0)
                 slotActionTriggered(QAbstractSlider::SliderSingleStepSub);
-        }
-        break;
+        } break;
         case Qt::Key_Right: {
             _cursorAnchorPos = newAnchor;
             ensureVisibleCursor();
             if (textCursor().position() == toPlainText().length())
                 slotActionTriggered(QAbstractSlider::SliderSingleStepAdd);
-        }
-        break;
+        } break;
         case Qt::Key_Up: {
             _cursorAnchorPos = newAnchor;
             ensureVisibleCursor();
@@ -610,17 +618,15 @@ void ListerTextArea::keyPressEvent(QKeyEvent * ke)
             getCursorPosition(x, y);
             if (y == 0)
                 slotActionTriggered(QAbstractSlider::SliderSingleStepSub);
-        }
-        break;
+        } break;
         case Qt::Key_Down: {
             _cursorAnchorPos = newAnchor;
             ensureVisibleCursor();
             int x, y;
             getCursorPosition(x, y);
-            if (y >= _sizeY-1)
+            if (y >= _sizeY - 1)
                 slotActionTriggered(QAbstractSlider::SliderSingleStepAdd);
-        }
-        break;
+        } break;
         case Qt::Key_PageDown: {
             _cursorAnchorPos = newAnchor;
             ensureVisibleCursor();
@@ -630,16 +636,16 @@ void ListerTextArea::keyPressEvent(QKeyEvent * ke)
             slotActionTriggered(QAbstractSlider::SliderPageStepAdd);
             y += _sizeY - _skippedLines;
             if (y > _rowContent.count()) {
-                y = _rowContent.count() - 1;
+                y = static_cast<int>(_rowContent.count()) - 1;
                 if (y > 0)
-                    x = _rowContent[ y - 1 ].length();
+                    x = static_cast<int>(_rowContent[y - 1].length());
                 else
                     x = 0;
             }
             _cursorPos = textToFilePositionOnScreen(x, y, _cursorAtFirstColumn);
             setCursorPositionInDocument(_cursorPos, _cursorAtFirstColumn);
         }
-        return;
+            return;
         case Qt::Key_PageUp: {
             _cursorAnchorPos = newAnchor;
             ensureVisibleCursor();
@@ -655,7 +661,7 @@ void ListerTextArea::keyPressEvent(QKeyEvent * ke)
             _cursorPos = textToFilePositionOnScreen(x, y, _cursorAtFirstColumn);
             setCursorPositionInDocument(_cursorPos, _cursorAtFirstColumn);
         }
-        return;
+            return;
         }
     }
     if (ke->modifiers() == Qt::ControlModifier) {
@@ -706,7 +712,7 @@ void ListerTextArea::keyPressEvent(QKeyEvent * ke)
     handleAnchorChange(oldAnchor);
 }
 
-void ListerTextArea::mousePressEvent(QMouseEvent * e)
+void ListerTextArea::mousePressEvent(QMouseEvent *e)
 {
     KTextEdit::mousePressEvent(e);
     // do change anchor only when shift is not pressed
@@ -715,7 +721,7 @@ void ListerTextArea::mousePressEvent(QMouseEvent * e)
     }
 }
 
-void ListerTextArea::mouseDoubleClickEvent(QMouseEvent * e)
+void ListerTextArea::mouseDoubleClickEvent(QMouseEvent *e)
 {
     _cursorAnchorPos = -1;
     const int oldAnchor = textCursor().anchor();
@@ -723,7 +729,7 @@ void ListerTextArea::mouseDoubleClickEvent(QMouseEvent * e)
     handleAnchorChange(oldAnchor);
 }
 
-void ListerTextArea::mouseMoveEvent(QMouseEvent * e)
+void ListerTextArea::mouseMoveEvent(QMouseEvent *e)
 {
     if (e->pos().y() < 0) {
         slotActionTriggered(QAbstractSlider::SliderSingleStepSub);
@@ -733,11 +739,10 @@ void ListerTextArea::mouseMoveEvent(QMouseEvent * e)
     KTextEdit::mouseMoveEvent(e);
 }
 
-void ListerTextArea::wheelEvent(QWheelEvent * e)
+void ListerTextArea::wheelEvent(QWheelEvent *e)
 {
     int delta = e->angleDelta().y();
     if (delta) {
-
         // zooming
         if (e->modifiers() & Qt::ControlModifier) {
             e->accept();
@@ -780,8 +785,7 @@ void ListerTextArea::slotActionTriggered(int action)
         if (endPos <= _lastPageStartPos) {
             _screenStartPos = endPos;
         }
-    }
-    break;
+    } break;
     case QAbstractSlider::SliderSingleStepSub: {
         if (_screenStartPos == 0) {
             break;
@@ -808,7 +812,7 @@ void ListerTextArea::slotActionTriggered(int action)
 
         const QByteArray chunk = _lister->cacheChunk(readPos, maxSize);
 
-        int from = chunk.size();
+        qsizetype from = chunk.size();
         while (from > 0) {
             from--;
             from = chunk.lastIndexOf(encodedEnter, from);
@@ -816,8 +820,8 @@ void ListerTextArea::slotActionTriggered(int action)
                 from = 0;
                 break;
             }
-            const int backRef = std::max(from - 20, 0);
-            const int size = from - backRef + encodedEnter.size();
+            const qsizetype backRef = std::max(from - 20, qsizetype(0));
+            const qsizetype size = from - backRef + encodedEnter.size();
             const QString decoded = _lister->codec()->toUnicode(chunk.mid(backRef, size));
             if (decoded.endsWith(QLatin1String("\n"))) {
                 if (from < (chunk.size() - encodedEnter.size())) {
@@ -834,8 +838,7 @@ void ListerTextArea::slotActionTriggered(int action)
             readLines(readPos, readPos, 1);
         }
         _screenStartPos = previousPos;
-    }
-    break;
+    } break;
     case QAbstractSlider::SliderPageStepAdd: {
         _skippedLines = 0;
 
@@ -849,8 +852,7 @@ void ListerTextArea::slotActionTriggered(int action)
                 break;
             }
         }
-    }
-    break;
+    } break;
     case QAbstractSlider::SliderPageStepSub: {
         _skippedLines = 0;
 
@@ -859,7 +861,7 @@ void ListerTextArea::slotActionTriggered(int action)
         }
 
         if (_hexMode) {
-            const int bytesPerRow = _lister->hexBytesPerLine(_sizeX);
+            const qsizetype bytesPerRow = _lister->hexBytesPerLine(_sizeX);
             _screenStartPos = (_screenStartPos / bytesPerRow) * bytesPerRow;
             _screenStartPos -= _sizeY * bytesPerRow;
             if (_screenStartPos < 0) {
@@ -880,8 +882,8 @@ void ListerTextArea::slotActionTriggered(int action)
         const QByteArray chunk = _lister->cacheChunk(readPos, maxSize);
         maxSize = chunk.size();
 
-        int sizeY = _sizeY + 1;
-        int origSizeY = sizeY;
+        qsizetype sizeY = _sizeY + 1;
+        qsizetype origSizeY = sizeY;
         qint64 from = maxSize;
         qint64 lastEnter = maxSize;
 
@@ -920,7 +922,7 @@ void ListerTextArea::slotActionTriggered(int action)
             }
 
             if (locs.count() >= _sizeY) {
-                _screenStartPos = locs[ locs.count() - _sizeY ];
+                _screenStartPos = locs[locs.count() - _sizeY];
             } else if (from != 0) {
                 origSizeY += locs.count() + 1;
                 sizeY = origSizeY;
@@ -930,8 +932,7 @@ void ListerTextArea::slotActionTriggered(int action)
             }
         }
 
-    }
-    break;
+    } break;
     case QAbstractSlider::SliderToMinimum:
         _screenStartPos = 0;
         break;
@@ -939,7 +940,7 @@ void ListerTextArea::slotActionTriggered(int action)
         _screenStartPos = _lastPageStartPos;
         break;
     case QAbstractSlider::SliderMove: {
-        if (_inSliderOp)  // self created call?
+        if (_inSliderOp) // self created call?
             return;
         qint64 pos = _lister->scrollBar()->sliderPosition();
 
@@ -959,7 +960,7 @@ void ListerTextArea::slotActionTriggered(int action)
                 const int bytesPerRow = _lister->hexBytesPerLine(_sizeX);
                 pos = (pos / bytesPerRow) * bytesPerRow;
             } else {
-                const int maxSize = _sizeX * _sizeY * MAX_CHAR_LENGTH;
+                const qsizetype maxSize = _sizeX * _sizeY * MAX_CHAR_LENGTH;
                 qint64 readPos = pos - maxSize;
                 if (readPos < 0)
                     readPos = 0;
@@ -975,8 +976,7 @@ void ListerTextArea::slotActionTriggered(int action)
         }
 
         _screenStartPos = pos;
-    }
-    break;
+    } break;
     case QAbstractSlider::SliderNoAction:
         break;
     };
@@ -1008,13 +1008,13 @@ void ListerTextArea::ensureVisibleCursor()
         return;
     }
 
-    int delta = _sizeY / 2;
+    qsizetype delta = _sizeY / 2;
     if (delta == 0)
         delta++;
 
     qint64 newScreenStart = _cursorPos;
     while (delta) {
-        const int maxSize = _sizeX * MAX_CHAR_LENGTH;
+        const qsizetype maxSize = _sizeX * MAX_CHAR_LENGTH;
         qint64 readPos = newScreenStart - maxSize;
         if (readPos < 0)
             readPos = 0;
@@ -1111,7 +1111,9 @@ void ListerTextArea::zoomOut(int range)
     redrawTextArea();
 }
 
-ListerPane::ListerPane(Lister *lister, QWidget *parent) : QWidget(parent), _lister(lister)
+ListerPane::ListerPane(Lister *lister, QWidget *parent)
+    : QWidget(parent)
+    , _lister(lister)
 {
 }
 
@@ -1145,7 +1147,8 @@ bool ListerPane::handleCloseEvent(QEvent *e)
     return false;
 }
 
-ListerBrowserExtension::ListerBrowserExtension(Lister * lister) : KParts::BrowserExtension(lister)
+ListerBrowserExtension::ListerBrowserExtension(Lister *lister)
+    : KParts::NavigationExtension(lister)
 {
     _lister = lister;
 
@@ -1166,28 +1169,33 @@ void ListerBrowserExtension::print()
 class ListerEncodingMenu : public KrRemoteEncodingMenu
 {
 public:
-    ListerEncodingMenu(Lister *lister, const QString &text, const QString &icon, KActionCollection *parent) :
-            KrRemoteEncodingMenu(text, icon, parent), _lister(lister) {
+    ListerEncodingMenu(Lister *lister, const QString &text, const QString &icon, KActionCollection *parent)
+        : KrRemoteEncodingMenu(text, icon, parent)
+        , _lister(lister)
+    {
     }
 
 protected:
-    QString currentCharacterSet() override {
+    QString currentCharacterSet() override
+    {
         return _lister->characterSet();
     }
 
-    void chooseDefault() override {
+    void chooseDefault() override
+    {
         _lister->setCharacterSet(QString());
     }
 
-    void chooseEncoding(QString encodingName) override {
-        QString charset = KCharsets::charsets()->encodingForName(encodingName);
-        _lister->setCharacterSet(charset);
+    void chooseEncoding(QString encodingName) override
+    {
+        _lister->setCharacterSet(encodingName);
     }
 
-    Lister * _lister;
+    Lister *_lister;
 };
 
-Lister::Lister(QWidget *parent) : KParts::ReadOnlyPart(parent)
+Lister::Lister(QWidget *parent)
+    : KParts::ReadOnlyPart(parent)
 {
     setXMLFile("krusaderlisterui.rc");
 
@@ -1202,12 +1210,12 @@ Lister::Lister(QWidget *parent) : KParts::ReadOnlyPart(parent)
     _actionPrint = new QAction(Icon("document-print"), i18n("Print..."), this);
     connect(_actionPrint, &QAction::triggered, this, &Lister::print);
     actionCollection()->addAction("print", _actionPrint);
-    actionCollection()->setDefaultShortcut(_actionPrint, Qt::CTRL + Qt::Key_P);
+    actionCollection()->setDefaultShortcut(_actionPrint, Qt::CTRL | Qt::Key_P);
 
     _actionSearch = new QAction(Icon("system-search"), i18n("Search"), this);
     connect(_actionSearch, &QAction::triggered, this, &Lister::searchAction);
     actionCollection()->addAction("search", _actionSearch);
-    actionCollection()->setDefaultShortcut(_actionSearch, Qt::CTRL + Qt::Key_F);
+    actionCollection()->setDefaultShortcut(_actionSearch, Qt::CTRL | Qt::Key_F);
 
     _actionSearchNext = new QAction(Icon("go-down"), i18n("Search next"), this);
     connect(_actionSearchNext, &QAction::triggered, this, &Lister::searchNext);
@@ -1217,21 +1225,21 @@ Lister::Lister(QWidget *parent) : KParts::ReadOnlyPart(parent)
     _actionSearchPrev = new QAction(Icon("go-up"), i18n("Search previous"), this);
     connect(_actionSearchPrev, &QAction::triggered, this, &Lister::searchPrev);
     actionCollection()->addAction("search_prev", _actionSearchPrev);
-    actionCollection()->setDefaultShortcut(_actionSearchPrev, Qt::SHIFT + Qt::Key_F3);
+    actionCollection()->setDefaultShortcut(_actionSearchPrev, Qt::SHIFT | Qt::Key_F3);
 
     _actionJumpToPosition = new QAction(Icon("go-jump"), i18n("Jump to position"), this);
     connect(_actionJumpToPosition, &QAction::triggered, this, &Lister::jumpToPosition);
     actionCollection()->addAction("jump_to_position", _actionJumpToPosition);
-    actionCollection()->setDefaultShortcut(_actionJumpToPosition, Qt::CTRL + Qt::Key_G);
+    actionCollection()->setDefaultShortcut(_actionJumpToPosition, Qt::CTRL | Qt::Key_G);
 
     _actionHexMode = new QAction(Icon("document-preview"), i18n("Hex mode"), this);
     connect(_actionHexMode, &QAction::triggered, this, &Lister::toggleHexMode);
     actionCollection()->addAction("hex_mode", _actionHexMode);
-    actionCollection()->setDefaultShortcut(_actionHexMode, Qt::CTRL + Qt::Key_H);
+    actionCollection()->setDefaultShortcut(_actionHexMode, Qt::CTRL | Qt::Key_H);
 
     new ListerEncodingMenu(this, i18n("Select charset"), "character-set", actionCollection());
 
-    QWidget * widget = new ListerPane(this, parent);
+    QWidget *widget = new ListerPane(this, parent);
     widget->setFocusPolicy(Qt::StrongFocus);
     auto *grid = new QGridLayout(widget);
     _textArea = new ListerTextArea(this, widget);
@@ -1245,7 +1253,7 @@ Lister::Lister(QWidget *parent) : KParts::ReadOnlyPart(parent)
     grid->addWidget(_scrollBar, 0, 1);
     _scrollBar->hide();
 
-    QWidget * statusWidget = new QWidget(widget);
+    QWidget *statusWidget = new QWidget(widget);
     auto *hbox = new QHBoxLayout(statusWidget);
 
     _listerLabel = new QLabel(i18n("Lister:"), statusWidget);
@@ -1284,7 +1292,7 @@ Lister::Lister(QWidget *parent) : KParts::ReadOnlyPart(parent)
     hbox->addWidget(_searchPrevButton);
     _searchOptions = new QPushButton(i18n("Options"), statusWidget);
     _searchOptions->setToolTip(i18n("Modify search behavior"));
-    auto * menu = new QMenu();
+    auto *menu = new QMenu();
     _fromCursorAction = menu->addAction(i18n("From cursor"));
     _fromCursorAction->setCheckable(true);
     _fromCursorAction->setChecked(true);
@@ -1340,13 +1348,14 @@ bool Lister::openUrl(const QUrl &listerUrl)
 
         KIO::TransferJob *downloadJob = KIO::get(listerUrl, KIO::NoReload, KIO::HideProgressInfo);
 
-        connect(downloadJob, &KIO::TransferJob::data, this, [=](KIO::Job*, QByteArray array) {
+        connect(downloadJob, &KIO::TransferJob::data, this, [=](KIO::Job *, QByteArray array) {
             if (array.size() != 0) {
                 _tempFile->write(array);
-            } });
+            }
+        });
         connect(downloadJob, &KIO::TransferJob::result, this, [=](KJob *job) {
             _tempFile->flush();
-            if (job->error()) {   /* any error occurred? */
+            if (job->error()) { /* any error occurred? */
                 auto *kioJob = qobject_cast<KIO::TransferJob *>(job);
                 KMessageBox::error(_textArea, i18n("Error reading file %1.", kioJob->url().toDisplayString(QUrl::PreferLocalFile)));
             }
@@ -1420,7 +1429,7 @@ qint64 Lister::getFileSize()
     return QFile(_filePath).size();
 }
 
-void Lister::guiActivateEvent(KParts::GUIActivateEvent * event)
+void Lister::guiActivateEvent(KParts::GUIActivateEvent *event)
 {
     if (event->activated()) {
         slotUpdate();
@@ -1539,7 +1548,7 @@ void Lister::search(const bool forward, const bool restart)
                 setColor(false, false);
                 return;
             }
-            _searchHexQuery.push_back((char) c);
+            _searchHexQuery.push_back((char)c);
         }
     } else {
         _searchQuery.setContent(_searchLineEdit->text(), caseSensitive, matchWholeWord, codec()->name(), regExp);
@@ -1618,7 +1627,7 @@ void Lister::slotSearchMore()
     qint64 byteCounter = 0;
 
     if (_searchHexadecimal) {
-        const int ndx = _searchIsForward ? chunk.indexOf(_searchHexQuery) : chunk.lastIndexOf(_searchHexQuery);
+        const qsizetype ndx = _searchIsForward ? chunk.indexOf(_searchHexQuery) : chunk.lastIndexOf(_searchHexQuery);
         if (chunkSize > _searchHexQuery.length()) {
             if (_searchIsForward) {
                 _searchPosition = searchPos + chunkSize;
@@ -1660,9 +1669,8 @@ void Lister::slotSearchMore()
 
                 if (_searchQuery.checkLine(row, !_searchIsForward)) {
                     QByteArray cachedBuffer = chunk.mid(static_cast<int>(rowStart), static_cast<int>(chunkSize - rowStart));
-
-                    QTextStream stream(&cachedBuffer);
-                    stream.setCodec(_codec);
+                    QString decoded = _codec->toUnicode(cachedBuffer);
+                    QTextStream stream(&decoded);
 
                     stream.read(_searchQuery.matchIndex());
                     foundAnchor = searchPos + rowStart + stream.pos();
@@ -1834,7 +1842,7 @@ void Lister::updateProgressBar()
     }
 
     const qint64 pcnt = (_fileSize == 0) ? 1000 : (2001 * _searchPosition) / _fileSize / 2;
-    const auto pctInt = (int) pcnt;
+    const auto pctInt = (int)pcnt;
     if (_searchProgressBar->value() != pctInt)
         _searchProgressBar->setValue(pctInt);
 }
@@ -1842,8 +1850,7 @@ void Lister::updateProgressBar()
 void Lister::jumpToPosition()
 {
     bool ok = true;
-    QString res = QInputDialog::getText(_textArea, i18n("Jump to position"), i18n("Text position:"),
-                                        QLineEdit::Normal, "0", &ok);
+    QString res = QInputDialog::getText(_textArea, i18n("Jump to position"), i18n("Text position:"), QLineEdit::Normal, "0", &ok);
     if (!ok)
         return;
 
@@ -1893,7 +1900,7 @@ void Lister::saveAs()
     urlList << sourceUrl;
 
     KIO::Job *job = KIO::copy(urlList, url);
-    job->setUiDelegate(new KIO::JobUiDelegate());
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate());
     KIO::getJobTracker()->registerJob(job);
     job->uiDelegate()->setAutoErrorHandlingEnabled(true);
 }
@@ -1923,7 +1930,7 @@ void Lister::saveSelected()
     connect(saveJob, &KIO::TransferJob::dataReq, this, &Lister::slotDataSend);
     connect(saveJob, &KIO::TransferJob::result, this, &Lister::slotSendFinished);
 
-    saveJob->setUiDelegate(new KIO::JobUiDelegate());
+    saveJob->setUiDelegate(KIO::createDefaultJobUiDelegate());
     KIO::getJobTracker()->registerJob(saveJob);
     saveJob->uiDelegate()->setAutoErrorHandlingEnabled(true);
 
@@ -1939,7 +1946,7 @@ void Lister::slotDataSend(KIO::Job *, QByteArray &array)
     qint64 max = _saveEnd - _savePosition;
     if (max > 1000)
         max = 1000;
-    array = cacheChunk(_savePosition, (int) max);
+    array = cacheChunk(_savePosition, (int)max);
     _savePosition += array.size();
 }
 
@@ -1948,13 +1955,15 @@ void Lister::slotSendFinished(KJob *)
     _actionSaveSelected->setEnabled(true);
 }
 
-void Lister::setCharacterSet(const QString& set)
+void Lister::setCharacterSet(const QString &set)
 {
     _characterSet = set;
     if (_characterSet.isEmpty()) {
         _codec = QTextCodec::codecForLocale();
     } else {
-        _codec = KCharsets::charsets()->codecForName(_characterSet);
+        // Should move from this with KF6 migration
+        _codec = QTextCodec::codecForName(_characterSet.toUtf8());
+        Q_ASSERT(_codec != nullptr);
     }
     _textArea->redrawTextArea(true);
 }
@@ -1973,7 +1982,7 @@ void Lister::print()
     QScopedPointer<QPrintDialog> printDialog(new QPrintDialog(&printer, _textArea));
 
     if (hasSelection) {
-        printDialog->addEnabledOption(QAbstractPrintDialog::PrintSelection);
+        printDialog->setOption(QAbstractPrintDialog::PrintSelection);
     }
 
     if (!printDialog->exec()) {
@@ -1981,9 +1990,8 @@ void Lister::print()
     }
 
     if (printer.pageOrder() == QPrinter::LastPageFirst) {
-        switch (KMessageBox::warningContinueCancel(_textArea,
-                i18n("Reverse printing is not supported. Continue with normal printing?"))) {
-        case KMessageBox::Continue :
+        switch (KMessageBox::warningContinueCancel(_textArea, i18n("Reverse printing is not supported. Continue with normal printing?"))) {
+        case KMessageBox::Continue:
             break;
         default:
             return;
@@ -1992,7 +2000,7 @@ void Lister::print()
     QPainter painter;
     painter.begin(&printer);
 
-    const QString dateString = QDate::currentDate().toString(Qt::SystemLocaleShortDate);
+    const QString dateString = QLocale().toString(QDate::currentDate(), QLocale::ShortFormat);
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     const QRect pageRect = printer.pageLayout().paintRectPixels(printer.resolution());
@@ -2002,7 +2010,7 @@ void Lister::print()
     const QRect drawingRect(0, 0, pageRect.width(), pageRect.height());
 
     const QFont normalFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
-    const QFont fixedFont  = QFontDatabase::systemFont(QFontDatabase::FixedFont);
+    const QFont fixedFont = QFontDatabase::systemFont(QFontDatabase::FixedFont);
 
     const QFontMetrics fmNormal(normalFont);
     const int normalFontHeight = fmNormal.height();
@@ -2056,7 +2064,7 @@ void Lister::print()
 
         painter.setFont(fixedFont);
         int yOffset = normalFontHeight + 1;
-        foreach (const QString &row, rows) {
+        for (const QString &row : std::as_const(rows)) {
             painter.drawText(0, yOffset + fixedFontHeight, row);
             yOffset += fixedFontHeight;
         }
@@ -2069,7 +2077,7 @@ QStringList Lister::readLines(qint64 &filePos, const qint64 endPos, const int co
         return readHexLines(filePos, endPos, columns, lines);
     }
     QStringList list;
-    const int maxBytes = std::min(columns * lines * MAX_CHAR_LENGTH, (int) (endPos - filePos));
+    const int maxBytes = std::min(columns * lines * MAX_CHAR_LENGTH, (int)(endPos - filePos));
     if (maxBytes <= 0) {
         return list;
     }
@@ -2090,7 +2098,7 @@ QStringList Lister::readLines(qint64 &filePos, const qint64 endPos, const int co
         }
 
         // replace unreadable characters
-        if ((chr[ 0 ] < 32) && (chr[ 0 ] != '\n') && (chr[ 0 ] != '\t')) {
+        if ((chr[0] < QChar(32)) && (chr[0] != '\n') && (chr[0] != '\t')) {
             chr = QChar(' ');
         }
 
@@ -2108,7 +2116,7 @@ QStringList Lister::readLines(qint64 &filePos, const qint64 endPos, const int co
 
         // handle tab
         if (chr == "\t") {
-            const int tabLength = _textArea->tabWidth() - (row.length() % _textArea->tabWidth());
+            const qsizetype tabLength = _textArea->tabWidth() - (row.length() % _textArea->tabWidth());
             if (row.length() + tabLength > columns) {
                 list << row;
                 row = "";
@@ -2169,7 +2177,7 @@ QStringList Lister::readHexLines(qint64 &filePos, const qint64 endPos, const int
     QStringList list;
 
     const qint64 choppedPos = (filePos / bytesPerRow) * bytesPerRow;
-    const int maxBytes = std::min(bytesPerRow * lines, (int) (endPos - choppedPos));
+    const int maxBytes = std::min(bytesPerRow * lines, (int)(endPos - choppedPos));
     if (maxBytes <= 0)
         return list;
 
@@ -2232,7 +2240,7 @@ int Lister::hexIndexToPosition(const int columns, const int index)
     const int bytesPerRow = hexBytesPerLine(columns);
     const int finalIndex = std::min(index, bytesPerRow);
 
-    return positionDigits + 4 + (3*finalIndex);
+    return positionDigits + 4 + (3 * finalIndex);
 }
 
 int Lister::hexPositionToIndex(const int columns, const int position)
