@@ -9,12 +9,13 @@
 // QtGui
 #include <QMouseEvent>
 
-#include <KConfigCore/KSharedConfig>
+#include <KSharedConfig>
 
 #include "../defaults.h"
 #include "../krglobal.h"
 
-ViewerTabWidget::ViewerTabWidget(QWidget *parent) : QTabWidget(parent)
+ViewerTabWidget::ViewerTabWidget(QWidget *parent)
+    : QTabWidget(parent)
 {
     setTabBar(new ViewerTabBar(this));
 }
@@ -32,7 +33,6 @@ void ViewerTabWidget::adjustViewerTabBarVisibility()
     return;
 }
 
-
 ViewerTabBar *ViewerTabWidget::tabBar() const
 {
     return dynamic_cast<ViewerTabBar *>(QTabWidget::tabBar());
@@ -49,7 +49,7 @@ void ViewerTabBar::mousePressEvent(QMouseEvent *e)
 
     setCurrentIndex(clickedTab);
 
-    if (e->button() == Qt::MidButton) {
+    if (e->button() == Qt::MiddleButton) {
         // close the current tab
         emit closeTabSignal(clickedTab);
     }
