@@ -7,8 +7,8 @@
 */
 
 #include "krcolorcache.h"
-#include "../krglobal.h"
 #include "../defaults.h"
+#include "../krglobal.h"
 
 // QtCore
 #include <QDebug>
@@ -19,10 +19,14 @@
 // QtWidgets
 #include <QApplication>
 
-#include <KConfigCore/KSharedConfig>
+#include <KSharedConfig>
 
 // Macro: set target = col, if col is valid
-#define SETCOLOR(target, col) { if (col.isValid()) target = col; }
+#define SETCOLOR(target, col)                                                                                                                                  \
+    {                                                                                                                                                          \
+        if (col.isValid())                                                                                                                                     \
+            target = col;                                                                                                                                      \
+    }
 
 // Static class, which lists all allowed keywords for a quick access.
 // Just call a method to initialize it.
@@ -32,13 +36,14 @@ class KrColorSettingNames
     static QMap<QString, bool> s_numNames;
     static QMap<QString, bool> s_boolNames;
     static void initialize();
+
 public:
     static QStringList getColorNames();
-    static bool isColorNameValid(const QString & settingName);
+    static bool isColorNameValid(const QString &settingName);
     static QStringList getNumNames();
-    static bool isNumNameValid(const QString & settingName);
+    static bool isNumNameValid(const QString &settingName);
     static QStringList getBoolNames();
-    static bool isBoolNameValid(const QString & settingName);
+    static bool isBoolNameValid(const QString &settingName);
 } krColorSettingNames;
 
 QMap<QString, bool> KrColorSettingNames::s_colorNames;
@@ -93,7 +98,7 @@ QStringList KrColorSettingNames::getColorNames()
     return s_colorNames.keys();
 }
 
-bool KrColorSettingNames::isColorNameValid(const QString & settingName)
+bool KrColorSettingNames::isColorNameValid(const QString &settingName)
 {
     initialize();
     return s_colorNames.contains(settingName);
@@ -105,7 +110,7 @@ QStringList KrColorSettingNames::getNumNames()
     return s_numNames.keys();
 }
 
-bool KrColorSettingNames::isNumNameValid(const QString & settingName)
+bool KrColorSettingNames::isNumNameValid(const QString &settingName)
 {
     initialize();
     return s_numNames.contains(settingName);
@@ -117,14 +122,12 @@ QStringList KrColorSettingNames::getBoolNames()
     return s_boolNames.keys();
 }
 
-bool KrColorSettingNames::isBoolNameValid(const QString & settingName)
+bool KrColorSettingNames::isBoolNameValid(const QString &settingName)
 {
     initialize();
     return s_boolNames.contains(settingName);
 }
 
-
-
 /*
 KrColorSettings implementation. Contains all properties in QMaps. loadFromConfig initializes them from krConfig.
 */
@@ -142,7 +145,7 @@ void KrColorSettingsImpl::loadFromConfig()
 {
     KConfigGroup group(krConfig, "Colors");
     QStringList names = KrColorSettingNames::getColorNames();
-    for (auto & name : names) {
+    for (auto &name : names) {
         m_colorTextValues[name] = group.readEntry(name, QString());
         if (m_colorTextValues[name].count(',') == 2)
             m_colorValues[name] = group.readEntry(name, QColor());
@@ -150,13 +153,13 @@ void KrColorSettingsImpl::loadFromConfig()
             m_colorValues[name] = QColor();
     }
     names = KrColorSettingNames::getNumNames();
-    for (auto & name : names) {
+    for (auto &name : names) {
         if (!group.readEntry(name, QString()).isEmpty()) {
             m_numValues[name] = group.readEntry(name, 0);
         }
     }
     names = KrColorSettingNames::getBoolNames();
-    for (auto & name : names) {
+    for (auto &name : names) {
         if (!group.readEntry(name, QString()).isEmpty()) {
             m_boolValues[name] = group.readEntry(name, false);
         }
@@ -169,10 +172,10 @@ KrColorSettings::KrColorSettings()
     m_impl->loadFromConfig();
 }
 
-KrColorSettings::KrColorSettings(const KrColorSettings & src)
+KrColorSettings::KrColorSettings(const KrColorSettings &src)
 {
     m_impl = new KrColorSettingsImpl();
-    operator =(src);
+    operator=(src);
 }
 
 KrColorSettings::~KrColorSettings()
@@ -180,12 +183,12 @@ KrColorSettings::~KrColorSettings()
     delete m_impl;
 }
 
-const KrColorSettings & KrColorSettings::operator= (const KrColorSettings & src)
+const KrColorSettings &KrColorSettings::operator=(const KrColorSettings &src)
 {
-    if (this == & src)
-        return * this;
+    if (this == &src)
+        return *this;
     QStringList names = KrColorSettingNames::getColorNames();
-    for (auto & name : names) {
+    for (auto &name : names) {
         m_impl->m_colorTextValues[name] = src.m_impl->m_colorTextValues[name];
         m_impl->m_colorValues[name] = src.m_impl->m_colorValues[name];
     }
@@ -195,7 +198,7 @@ const KrColorSettings & KrColorSettings::operator= (const KrColorSettings & src)
     for (QMap<QString, bool>::Iterator it = src.m_impl->m_boolValues.begin(); it != src.m_impl->m_boolValues.end(); ++it) {
         m_impl->m_boolValues[it.key()] = it.value();
     }
-    return * this;
+    return *this;
 }
 
 QList<QString> KrColorSettings::getColorNames()
@@ -203,12 +206,12 @@ QList<QString> KrColorSettings::getColorNames()
     return KrColorSettingNames::getColorNames();
 }
 
-bool KrColorSettings::isColorNameValid(const QString & settingName)
+bool KrColorSettings::isColorNameValid(const QString &settingName)
 {
     return KrColorSettingNames::isColorNameValid(settingName);
 }
 
-bool KrColorSettings::setColorValue(const QString & settingName, const QColor & color)
+bool KrColorSettings::setColorValue(const QString &settingName, const QColor &color)
 {
     if (!isColorNameValid(settingName)) {
         qWarning() << "Invalid color setting name: " << settingName;
@@ -218,7 +221,7 @@ bool KrColorSettings::setColorValue(const QString & settingName, const QColor &
     return true;
 }
 
-QColor KrColorSettings::getColorValue(const QString & settingName) const
+QColor KrColorSettings::getColorValue(const QString &settingName) const
 {
     if (!isColorNameValid(settingName)) {
         qWarning() << "Invalid color setting name: " << settingName;
@@ -227,7 +230,7 @@ QColor KrColorSettings::getColorValue(const QString & settingName) const
     return m_impl->m_colorValues[settingName];
 }
 
-bool KrColorSettings::setColorTextValue(const QString & settingName, const QString & colorText)
+bool KrColorSettings::setColorTextValue(const QString &settingName, const QString &colorText)
 {
     if (!isColorNameValid(settingName)) {
         qWarning() << "Invalid color setting name: " << settingName;
@@ -237,7 +240,7 @@ bool KrColorSettings::setColorTextValue(const QString & settingName, const QStri
     return true;
 }
 
-QString KrColorSettings::getColorTextValue(const QString & settingName) const
+QString KrColorSettings::getColorTextValue(const QString &settingName) const
 {
     if (!isColorNameValid(settingName)) {
         qWarning() << "Invalid color setting name: " << settingName;
@@ -251,12 +254,12 @@ QList<QString> KrColorSettings::getNumNames()
     return KrColorSettingNames::getNumNames();
 }
 
-bool KrColorSettings::isNumNameValid(const QString & settingName)
+bool KrColorSettings::isNumNameValid(const QString &settingName)
 {
     return KrColorSettingNames::isNumNameValid(settingName);
 }
 
-bool KrColorSettings::setNumValue(const QString & settingName, int value)
+bool KrColorSettings::setNumValue(const QString &settingName, int value)
 {
     if (!isNumNameValid(settingName)) {
         qWarning() << "Invalid number setting name: " << settingName;
@@ -266,7 +269,7 @@ bool KrColorSettings::setNumValue(const QString & settingName, int value)
     return true;
 }
 
-int KrColorSettings::getNumValue(const QString & settingName, int defaultValue) const
+int KrColorSettings::getNumValue(const QString &settingName, int defaultValue) const
 {
     if (!isNumNameValid(settingName)) {
         qWarning() << "Invalid number setting name: " << settingName;
@@ -282,12 +285,12 @@ QList<QString> KrColorSettings::getBoolNames()
     return KrColorSettingNames::getBoolNames();
 }
 
-bool KrColorSettings::isBoolNameValid(const QString & settingName)
+bool KrColorSettings::isBoolNameValid(const QString &settingName)
 {
     return KrColorSettingNames::isBoolNameValid(settingName);
 }
 
-bool KrColorSettings::setBoolValue(const QString & settingName, bool value)
+bool KrColorSettings::setBoolValue(const QString &settingName, bool value)
 {
     if (!isBoolNameValid(settingName)) {
         qWarning() << "Invalid bool setting name: " << settingName;
@@ -297,7 +300,7 @@ bool KrColorSettings::setBoolValue(const QString & settingName, bool value)
     return true;
 }
 
-int KrColorSettings::getBoolValue(const QString & settingName, bool defaultValue) const
+int KrColorSettings::getBoolValue(const QString &settingName, bool defaultValue) const
 {
     if (!isBoolNameValid(settingName)) {
         qWarning() << "Invalid bool setting name: " << settingName;
@@ -308,8 +311,6 @@ int KrColorSettings::getBoolValue(const QString & settingName, bool defaultValue
     return m_impl->m_boolValues[settingName];
 }
 
-
-
 KrColorItemType::KrColorItemType()
 {
     m_fileType = File;
@@ -328,26 +329,23 @@ KrColorItemType::KrColorItemType(FileType type, bool alternateBackgroundColor, b
     m_selectedItem = selectedItem;
 }
 
-KrColorItemType::KrColorItemType(const KrColorItemType & src)
+KrColorItemType::KrColorItemType(const KrColorItemType &src)
 {
-    operator= (src);
+    operator=(src);
 }
 
-const KrColorItemType & KrColorItemType::operator= (const KrColorItemType & src)
+const KrColorItemType &KrColorItemType::operator=(const KrColorItemType &src)
 {
-    if (this == & src)
-        return * this;
+    if (this == &src)
+        return *this;
     m_fileType = src.m_fileType;
     m_alternateBackgroundColor = src.m_alternateBackgroundColor;
     m_activePanel = src.m_activePanel;
     m_currentItem = src.m_currentItem;
     m_selectedItem = src.m_selectedItem;
-    return * this;
+    return *this;
 }
 
-
-
-
 /*
 KrColorCache implementation. Contains the KrColorSettings used for teh calculation and the cache for the results.
 getColors is the only method to call. All other are taken from the previous versions.
@@ -358,10 +356,10 @@ class KrColorCacheImpl
     QMap<QString, KrColorGroup> m_cachedColors;
     KrColorSettings m_colorSettings;
 
-    KrColorGroup getColors(const KrColorItemType & type) const;
-    static const QColor & setColorIfContrastIsSufficient(const QColor & background, const QColor & color1, const QColor & color2);
+    KrColorGroup getColors(const KrColorItemType &type) const;
+    static const QColor &setColorIfContrastIsSufficient(const QColor &background, const QColor &color1, const QColor &color2);
     QColor getForegroundColor(bool isActive) const;
-    QColor getSpecialForegroundColor(const QString & type, bool isActive) const;
+    QColor getSpecialForegroundColor(const QString &type, bool isActive) const;
     QColor getBackgroundColor(bool isActive) const;
     QColor getAlternateBackgroundColor(bool isActive) const;
     QColor getMarkedForegroundColor(bool isActive) const;
@@ -373,16 +371,15 @@ class KrColorCacheImpl
     QColor dimColor(QColor color, bool isBackgroundColor) const;
 };
 
-KrColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
+KrColorGroup KrColorCacheImpl::getColors(const KrColorItemType &type) const
 {
     KrColorGroup result;
     if (m_colorSettings.getBoolValue("KDE Default", _KDEDefaultColors)) {
         bool enableAlternateBackground = m_colorSettings.getBoolValue("Enable Alternate Background", _AlternateBackground);
 
         QPalette p = QGuiApplication::palette();
-        QColor background = enableAlternateBackground && type.m_alternateBackgroundColor ?
-                    p.color(QPalette::Active, QPalette::Base)
-                  :  p.color(QPalette::Active, QPalette::AlternateBase);
+        QColor background = enableAlternateBackground && type.m_alternateBackgroundColor ? p.color(QPalette::Active, QPalette::Base)
+                                                                                         : p.color(QPalette::Active, QPalette::AlternateBase);
         result.setBackground(background);
         result.setText(p.color(QPalette::Active, QPalette::Text));
         result.setHighlight(p.color(QPalette::Active, QPalette::Highlight));
@@ -408,21 +405,19 @@ KrColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
         isActive = true;
 
     // First calculate fore- and background.
-    QColor background = type.m_alternateBackgroundColor ?
-                        getAlternateBackgroundColor(isActive)
-                        : getBackgroundColor(isActive);
+    QColor background = type.m_alternateBackgroundColor ? getAlternateBackgroundColor(isActive) : getBackgroundColor(isActive);
     QColor foreground;
     switch (type.m_fileType) {
-    case KrColorItemType::Directory :
+    case KrColorItemType::Directory:
         foreground = getSpecialForegroundColor("Directory", isActive);
         break;
-    case KrColorItemType::Executable :
+    case KrColorItemType::Executable:
         foreground = getSpecialForegroundColor("Executable", isActive);
         break;
-    case KrColorItemType::InvalidSymlink :
+    case KrColorItemType::InvalidSymlink:
         foreground = getSpecialForegroundColor("Invalid Symlink", isActive);
         break;
-    case KrColorItemType::Symlink :
+    case KrColorItemType::Symlink:
         foreground = getSpecialForegroundColor("Symlink", isActive);
         break;
     default:
@@ -436,9 +431,7 @@ KrColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
     result.setText(foreground);
 
     // now the color of a marked item
-    QColor markedBackground = type.m_alternateBackgroundColor ?
-                              getAlternateMarkedBackgroundColor(isActive)
-                              : getMarkedBackgroundColor(isActive);
+    QColor markedBackground = type.m_alternateBackgroundColor ? getAlternateMarkedBackgroundColor(isActive) : getMarkedBackgroundColor(isActive);
     QColor markedForeground = getMarkedForegroundColor(isActive);
     if (!markedForeground.isValid()) // transparent
         // choose fore- or background, depending on its contrast compared to markedBackground
@@ -491,9 +484,9 @@ KrColorGroup KrColorCacheImpl::getColors(const KrColorItemType & type) const
     return result;
 }
 
-const QColor & KrColorCacheImpl::setColorIfContrastIsSufficient(const QColor & background, const QColor & color1, const QColor & color2)
+const QColor &KrColorCacheImpl::setColorIfContrastIsSufficient(const QColor &background, const QColor &color1, const QColor &color2)
 {
-#define sqr(x) ((x)*(x))
+#define sqr(x) ((x) * (x))
     int contrast = sqr(color1.red() - background.red()) + sqr(color1.green() - background.green()) + sqr(color1.blue() - background.blue());
 
     // if the contrast between background and color1 is too small, take color2 instead.
@@ -507,17 +500,19 @@ QColor KrColorCacheImpl::getForegroundColor(bool isActive) const
     QPalette p = QGuiApplication::palette();
     QColor color = p.color(QPalette::Active, QPalette::Text);
     SETCOLOR(color, m_colorSettings.getColorValue("Foreground"));
-    if (!isActive) SETCOLOR(color, m_colorSettings.getColorValue("Inactive Foreground"));
+    if (!isActive)
+        SETCOLOR(color, m_colorSettings.getColorValue("Inactive Foreground"));
     return color;
 }
 
-QColor KrColorCacheImpl::getSpecialForegroundColor(const QString & type, bool isActive) const
+QColor KrColorCacheImpl::getSpecialForegroundColor(const QString &type, bool isActive) const
 {
     QString colorName = "Inactive " + type + " Foreground";
     if (!isActive && m_colorSettings.getColorTextValue(colorName) == "Inactive Foreground")
         return getForegroundColor(false);
     QColor color = m_colorSettings.getColorValue(type + " Foreground");
-    if (!isActive) SETCOLOR(color, m_colorSettings.getColorValue(colorName));
+    if (!isActive)
+        SETCOLOR(color, m_colorSettings.getColorValue(colorName));
     if (!color.isValid())
         return getForegroundColor(isActive);
     return color;
@@ -527,7 +522,8 @@ QColor KrColorCacheImpl::getBackgroundColor(bool isActive) const
 {
     QColor color = QGuiApplication::palette().color(QPalette::Active, QPalette::Base);
     SETCOLOR(color, m_colorSettings.getColorValue("Background"));
-    if (!isActive) SETCOLOR(color, m_colorSettings.getColorValue("Inactive Background"));
+    if (!isActive)
+        SETCOLOR(color, m_colorSettings.getColorValue("Inactive Background"));
     return color;
 }
 
@@ -540,9 +536,7 @@ QColor KrColorCacheImpl::getAlternateBackgroundColor(bool isActive) const
         return getAlternateBackgroundColor(true);
     if (!isActive && m_colorSettings.getColorTextValue("Inactive Alternate Background") == "Inactive Background")
         return getBackgroundColor(false);
-    QColor color = isActive ?
-                   m_colorSettings.getColorValue("Alternate Background")
-                   : m_colorSettings.getColorValue("Inactive Alternate Background");
+    QColor color = isActive ? m_colorSettings.getColorValue("Alternate Background") : m_colorSettings.getColorValue("Inactive Alternate Background");
     if (!color.isValid())
         color = p.color(QPalette::Active, QPalette::AlternateBase);
     if (!color.isValid())
@@ -572,9 +566,7 @@ QColor KrColorCacheImpl::getMarkedBackgroundColor(bool isActive) const
         return getMarkedBackgroundColor(true);
     if (!isActive && m_colorSettings.getColorTextValue("Inactive Marked Background") == "Inactive Background")
         return getBackgroundColor(false);
-    return isActive ?
-           m_colorSettings.getColorValue("Marked Background")
-           : m_colorSettings.getColorValue("Inactive Marked Background");
+    return isActive ? m_colorSettings.getColorValue("Marked Background") : m_colorSettings.getColorValue("Inactive Marked Background");
 }
 
 QColor KrColorCacheImpl::getAlternateMarkedBackgroundColor(bool isActive) const
@@ -589,15 +581,14 @@ QColor KrColorCacheImpl::getAlternateMarkedBackgroundColor(bool isActive) const
         return getAlternateBackgroundColor(false);
     if (!isActive && m_colorSettings.getColorTextValue("Inactive Alternate Marked Background") == "Inactive Marked Background")
         return getMarkedBackgroundColor(false);
-    return isActive ?
-           m_colorSettings.getColorValue("Alternate Marked Background")
-           : m_colorSettings.getColorValue("Inactive Alternate Marked Background");
+    return isActive ? m_colorSettings.getColorValue("Alternate Marked Background") : m_colorSettings.getColorValue("Inactive Alternate Marked Background");
 }
 
 QColor KrColorCacheImpl::getCurrentForegroundColor(bool isActive) const
 {
     QColor color = m_colorSettings.getColorValue("Current Foreground");
-    if (!isActive) SETCOLOR(color, m_colorSettings.getColorValue("Inactive Current Foreground"));
+    if (!isActive)
+        SETCOLOR(color, m_colorSettings.getColorValue("Inactive Current Foreground"));
     return color;
 }
 
@@ -611,9 +602,7 @@ QColor KrColorCacheImpl::getCurrentBackgroundColor(bool isActive) const
         return getCurrentBackgroundColor(true);
     if (!isActive && m_colorSettings.getColorTextValue("Inactive Current Background") == "Inactive Background")
         return getBackgroundColor(false);
-    return isActive ?
-           m_colorSettings.getColorValue("Current Background")
-           : m_colorSettings.getColorValue("Inactive Current Background");
+    return isActive ? m_colorSettings.getColorValue("Current Background") : m_colorSettings.getColorValue("Inactive Current Background");
 }
 
 QColor KrColorCacheImpl::getCurrentMarkedForegroundColor(bool isActive) const
@@ -643,12 +632,7 @@ QColor KrColorCacheImpl::dimColor(QColor color, bool /* isBackgroundColor */) co
     return color;
 }
 
-
-
-
-
-
-KrColorCache * KrColorCache::m_instance = nullptr;
+KrColorCache *KrColorCache::m_instance = nullptr;
 
 KrColorCache::KrColorCache()
 {
@@ -660,30 +644,30 @@ KrColorCache::~KrColorCache()
     delete m_impl;
 }
 
-KrColorCache & KrColorCache::getColorCache()
+KrColorCache &KrColorCache::getColorCache()
 {
     if (!m_instance) {
         m_instance = new KrColorCache;
         m_instance->refreshColors();
     }
-    return * m_instance;
+    return *m_instance;
 }
 
-void KrColorCache::getColors(KrColorGroup  & result, const KrColorItemType & type) const
+void KrColorCache::getColors(KrColorGroup &result, const KrColorItemType &type) const
 {
     // for the cache lookup: calculate a unique key from the type
     char hashKey[128];
     switch (type.m_fileType) {
-    case KrColorItemType::Directory :
+    case KrColorItemType::Directory:
         strcpy(hashKey, "Directory");
         break;
-    case KrColorItemType::Executable :
+    case KrColorItemType::Executable:
         strcpy(hashKey, "Executable");
         break;
-    case KrColorItemType::InvalidSymlink :
+    case KrColorItemType::InvalidSymlink:
         strcpy(hashKey, "InvalidSymlink");
         break;
-    case KrColorItemType::Symlink :
+    case KrColorItemType::Symlink:
         strcpy(hashKey, "Symlink");
         break;
     default:
@@ -704,7 +688,7 @@ void KrColorCache::getColors(KrColorGroup  & result, const KrColorItemType & typ
         m_impl->m_cachedColors[hashKey] = m_impl->getColors(type);
 
     // get color group from cache
-    const KrColorGroup & col = m_impl->m_cachedColors[hashKey];
+    const KrColorGroup &col = m_impl->m_cachedColors[hashKey];
 
     // copy colors in question to result color group
     result.setBackground(col.background());
@@ -713,7 +697,7 @@ void KrColorCache::getColors(KrColorGroup  & result, const KrColorItemType & typ
     result.setHighlight(col.highlight());
 }
 
-bool KrColorCache::getDimSettings(QColor & dimColor, int & dimFactor)
+bool KrColorCache::getDimSettings(QColor &dimColor, int &dimFactor)
 {
     if (m_impl->m_colorSettings.getBoolValue("Dim Inactive Colors", false)) {
         dimFactor = m_impl->m_colorSettings.getNumValue("Dim Factor", 100);
@@ -725,7 +709,7 @@ bool KrColorCache::getDimSettings(QColor & dimColor, int & dimFactor)
     return false;
 }
 
-QColor KrColorCache::dimColor(const QColor & color, int dim, const QColor & targetColor)
+QColor KrColorCache::dimColor(const QColor &color, int dim, const QColor &targetColor)
 {
     return QColor((targetColor.red() * (100 - dim) + color.red() * dim) / 100,
                   (targetColor.green() * (100 - dim) + color.green() * dim) / 100,
@@ -740,11 +724,10 @@ void KrColorCache::refreshColors()
     emit colorsRefreshed();
 }
 
-void KrColorCache::setColors(const KrColorSettings & colorSettings)
+void KrColorCache::setColors(const KrColorSettings &colorSettings)
 {
     m_impl->m_cachedColors.clear();
     m_impl->m_colorSettings = colorSettings;
     QPixmapCache::clear(); // dimmed icons are cached
     emit colorsRefreshed();
 }
-
