@@ -5,7 +5,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef KRPANEL_H
 #define KRPANEL_H
 
@@ -20,11 +19,19 @@ class KrView;
 class KrPanel
 {
 public:
-    KrPanel(AbstractPanelManager *manager, ListPanel *panel, ListPanelFunc *func) :
-        gui(panel), func(func), view(nullptr), _manager(manager) {}
-    virtual ~KrPanel() {}
+    KrPanel(AbstractPanelManager *manager, ListPanel *panel, ListPanelFunc *func)
+        : gui(panel)
+        , func(func)
+        , view(nullptr)
+        , _manager(manager)
+    {
+    }
+    virtual ~KrPanel()
+    {
+    }
     QUrl virtualPath() const; // the current directory path of this panel
-    AbstractPanelManager *manager() const {
+    AbstractPanelManager *manager() const
+    {
         return _manager;
     }
     KrPanel *otherPanel() const;
@@ -33,7 +40,7 @@ public:
 
     ListPanel *const gui;
     ListPanelFunc *const func;
-    KrView *view;
+    KrView *view; // the view of file items in this panel
 
 protected:
     AbstractPanelManager *_manager;
