@@ -9,8 +9,8 @@
 #define SYNCHRONIZERDIRLIST_H
 
 // QtCore
-#include <QObject>
 #include <QHash>
+#include <QObject>
 
 #include <KIO/Job>
 
@@ -28,14 +28,15 @@ public:
     FileItem *first();
     FileItem *next();
 
-    inline const QString & url() {
+    inline const QString &url()
+    {
         return currentUrl;
     }
     bool load(const QString &urlIn, bool wait = false);
 
 public slots:
 
-    void slotEntries(KIO::Job * job, const KIO::UDSEntryList& entries);
+    void slotEntries(KIO::Job *job, const KIO::UDSEntryList &entries);
     void slotListResult(KJob *job);
 
 signals:
@@ -44,10 +45,10 @@ signals:
 private:
     QHashIterator<QString, FileItem *> *fileIterator; //< Point to a dictionary of file items
     QWidget *parentWidget;
-    bool     busy;
-    bool     result;
-    bool     ignoreHidden;
-    QString  currentUrl;
+    bool busy;
+    bool result;
+    bool ignoreHidden;
+    QString currentUrl;
 };
 
 #endif /* __SYNCHRONIZER_DIR_LIST_H__ */
