@@ -16,7 +16,9 @@ class KrPanel;
 class AbstractPanelManager
 {
 public:
-    virtual ~AbstractPanelManager() {}
+    virtual ~AbstractPanelManager()
+    {
+    }
     virtual bool isLeft() const = 0;
     virtual AbstractPanelManager *otherManager() const = 0;
     virtual KrPanel *currentPanel() const = 0;
@@ -24,5 +26,4 @@ public:
     virtual void duplicateTab(const QUrl &, KrPanel *nextTo = nullptr) = 0;
 };
 
-
 #endif // ABSTRACTPANELMANAGER_H
