@@ -11,7 +11,7 @@
 #include "krusader.h"
 #include "krusaderview.h"
 
-#include <KXmlGui/KActionCollection>
+#include <KActionCollection>
 
 KConfig *KrGlobal::config = nullptr;
 KMountMan *KrGlobal::mountMan = nullptr;
@@ -28,6 +28,9 @@ QKeySequence KrGlobal::copyShortcut;
 const int KrGlobal::sConfigVersion;
 int KrGlobal::sCurrentConfigVersion;
 
+bool KrGlobal::isWaylandPlatform = false;
+bool KrGlobal::isX11Platform = false;
+
 KrPanel *KrGlobal::activePanel()
 {
     return mainView->activePanel();
