@@ -9,7 +9,7 @@
 #ifndef KRLINECOUNTINGPROCESS_H
 #define KRLINECOUNTINGPROCESS_H
 
-#include <KCoreAddons/KProcess>
+#include <KProcess>
 
 /**
  * A KProcess which emits how many lines it is writing to stdout or stderr.
@@ -27,8 +27,8 @@ public slots:
     void receivedOutput(QByteArray = QByteArray());
 
 signals:
-    void newOutputLines(int);
-    void newErrorLines(int);
+    void newOutputLines(qsizetype);
+    void newErrorLines(qsizetype);
     void newOutputData(KProcess *, QByteArray &);
 
 private:
